@@ -2,11 +2,11 @@ package Weed::ArrayField;
 use strict;
 use warnings;
 
-our $VERSION = '0.0009';
+our $VERSION = '0.0011';
 
 use Weed;
 
-use constant DESCRIPTION => 'X3DArrayField : X3DField { }';
+our $DESCRIPTION = 'X3DArrayField : X3DField { }';
 
 1;
 __END__
