@@ -2,11 +2,11 @@ package Weed::Component::Core;
 use strict;
 use warnings;
 
-our $VERSION = '0.0009';
+our $VERSION = '0.0011';
 
 use Weed;
 
-use constant DESCRIPTION => '
+our $DESCRIPTION = '
 X3DComponentCore : X3DComponent {
   SFNode [in,out] metadata NULL [X3DMetadataObject]
 }
