@@ -2,11 +2,11 @@ package Weed::Component::Core::ChildNode;
 use strict;
 use warnings;
 
-our $VERSION = '0.0009';
+our $VERSION = '0.0011';
 
 use Weed;
 
-use constant DESCRIPTION => '
+our $DESCRIPTION = '
 X3DChildNode : X3DNode { 
 	SFNode [in,out] metadata NULL [X3DMetadataObject]
 }
