@@ -2,11 +2,11 @@ package Weed::Component::Grouping::BoundedObject;
 use strict;
 use warnings;
 
-our $VERSION = '0.0009';
+our $VERSION = '0.0011';
 
 use Weed;
 
-use constant DESCRIPTION => '
+our $DESCRIPTION = '
 X3DBoundedObject { 
   SFVec3f [] bboxCenter 0 0 0    (-\u221e,\u221e)
   SFVec3f [] bboxSize   -1 -1 -1 [0,\u221e) or \u22121 \u22121 \u22121
