@@ -2,11 +2,11 @@ package Weed::Field::MFNode;
 use strict;
 use warnings;
 
-our $VERSION = '0.0009';
+our $VERSION = '0.0011';
 
 use Weed;
 
-use constant DESCRIPTION => 'MFNode : X3DArrayField { }';
+our $DESCRIPTION = 'MFNode : X3DArrayField { }';
 
 1;
 __END__
