@@ -2,11 +2,11 @@ package Weed::FieldDefinition;
 use strict;
 use warnings;
 
-our $VERSION = '0.0009';
+our $VERSION = '0.0011';
 
 use Weed;
 
-use constant DESCRIPTION => 'X3DFieldDefinition { }';
+our $DESCRIPTION = 'X3DFieldDefinition { }';
 
 sub new {
 	my ( $self, $type, $in, $out, @args ) = @_;
@@ -42,6 +42,14 @@ sub createField {
 	return $field;
 }
 
+use Weed::Generator::Symbols;
+
+sub toString { sprintf $string_, $_[0]->getType }
+
+sub shutdown {
+	printf "%s->%s %s\n", $_[0]->PACKAGE, $_[0]->SUB, &toString($_[0]);
+}
+
 1;
 __END__
 
