@@ -2,11 +2,11 @@ package Weed::Universum;
 use strict;
 use warnings;
 
-our $VERSION = '0.0009';
+our $VERSION = '0.0011';
 
 use Weed;
 
-use constant DESCRIPTION => '
+our $DESCRIPTION = '
 X3DUniversum : X3DGroupingNode {
   MFNode  [in]     addChildren
   MFNode  [in]     removeChildren
